@@ -30,12 +30,12 @@ struct mapping
 };
 
 mapping maptab_data;
-int     maptab_fill;
-int     maptab_size;
+size_t  maptab_fill;
+size_t  maptab_size;
 
-void maptab_expand()
+static void maptab_expand(void)
 {
-  int bytes;
+  size_t bytes;
   maptab_size = maptab_size*2 + 100;
   bytes = maptab_size * sizeof(struct mapping);
   maptab_data = (mapping)realloc(maptab_data, bytes);
@@ -45,7 +45,7 @@ void maptab_expand()
   }
 }
 
-dev_t convert_to_dev_t(char *str)
+static dev_t convert_to_dev_t(char *str)
 {
   unsigned int result = 0;
   while (*str) {
@@ -57,7 +57,7 @@ dev_t convert_to_dev_t(char *str)
   return result;
 }
 
-void read_proc()
+static void read_proc(void)
 {
   unsigned int nread, pid, lo, hi, offs; unsigned long inode; char *p;
   char dev[80], buff[PATH_MAX + 300], *path;
@@ -107,7 +107,7 @@ void read_proc()
   closedir(d);
 }
 
-int sort_by_pid(mapping m1, mapping m2)
+static int sort_by_pid(mapping m1, mapping m2)
 {
   int delta;
   delta = m1->pid - m2->pid;
@@ -122,7 +122,7 @@ int sort_by_pid(mapping m1, mapping m2)
   return delta;
 }
 
-int sort_by_inode(mapping m1, mapping m2)
+static int sort_by_inode(mapping m1, mapping m2)
 {
   int delta;
   delta = m1->fs - m2->fs;
@@ -133,9 +133,10 @@ int sort_by_inode(mapping m1, mapping m2)
   return delta;
 }
 
-void register_path(unsigned int fs, unsigned int inode, char *path, int valid)
+static void register_path(unsigned int fs, unsigned int inode, char *path, int valid)
 {
-  int i; mapping m; char *copy=0;
+  size_t i;
+  mapping m; char *copy=0;
   for (i=0; i<maptab_fill; i++) {
     m = maptab_data + i;
     if ((m->path)&&(m->path[0]=='[')&&(m->fs == fs)&&(m->inode == inode)) {
@@ -146,7 +147,7 @@ void register_path(unsigned int fs, unsigned int inode, char *path, int valid)
   }
 }
 
-void scan_directory(char *dir)
+static void scan_directory(char *dir)
 {
   DIR *d; struct dirent *ent;
   struct stat info; int ok;
@@ -162,7 +163,7 @@ void scan_directory(char *dir)
   closedir(d);
 }
 
-void scan_fpath(char *fn)
+static void scan_fpath(const char *fn)
 {
   char *p;
   FILE *f = fopen(fn, "r");
@@ -180,7 +181,7 @@ void scan_fpath(char *fn)
   fclose(f);
 }
 
-void printline(char *str)
+static void printline(char *str)
 {
   int len;
   if (wide) goto done;
@@ -194,7 +195,7 @@ done:
   printf("%s\n", str);
 }
 
-void summarize_usage()
+static void summarize_usage(void)
 {
   char buffer[8192];
   unsigned int grand, i, offs, fs, inode, pid, lo, hi, scan, tail, total;
@@ -245,7 +246,7 @@ void summarize_usage()
   printf("%7dk\n", grand/1024);
 }
 
-void usage(char *prog)
+static void usage(char *prog)
 {
   fprintf(stderr,"usage: %s [-w]\n", prog);
   exit(1);
